import greenfoot.*;  // (World, Actor, GreenfootImage, and Greenfoot)

import java.util.List;
import java.util.ArrayList;
import java.awt.Color;
import java.awt.Font;
import java.util.Calendar;

/**
 * Un ours peut se déplacer sur une surface en fonction des touches pressées.
 * 
 * @author Bernard Gisin
 * @version 0.1
 */
public class cOurs extends Actor
{
    private static final int NORTH = 1;
    private static final int EAST  = 2;
    private static final int SOUTH = 3;
    private static final int WEST  = 4;

    private int direction = EAST;
    public int leavesEaten = 0;  // nombre de feuilles mangées

    public cOurs()
    {
        setDirection(EAST);
        leavesEaten = 0;
    }

    /**
     * act()  est appelé plusieurs fois par secondes.
     * C'est a travers lui que les événements sont testés.
     */
    public void act()
    {
        processKeys();
        
        if(foundLeaf()) {
            eatLeaf();
        }
    }
    
    /**
     * Se déplace en fonction des touches pressées
     */
    private void processKeys() {
        if(Greenfoot.isKeyDown("up")) {
            setDirection(NORTH);
            move();
        } else if(Greenfoot.isKeyDown("right")) {
            setDirection(EAST);
            move();
        } else if(Greenfoot.isKeyDown("down")) {
            setDirection(SOUTH);
            move();
        } else if(Greenfoot.isKeyDown("left")) {
            setDirection(WEST);
            move();
        }    
    }

    /**
     * Check whether there is a leaf in the same cell as we are.
     */
    public boolean foundLeaf()
    {
        Actor leaf = getOneObjectAtOffset(0, 0, Leaf.class);
        if(leaf != null) {
            return true;
        }
        else {
            return false;
        }
    }
    
    /**
     * Mange une feuille, compte le nombre de feuilles mangées et
     * test si elles ont toutes été mangée.
     */
    public void eatLeaf()
    {
        Actor leaf = getOneObjectAtOffset(0, 0, Leaf.class);
        if(leaf != null) {
            // eat the leaf...
            getWorld().removeObject(leaf);
            leavesEaten = leavesEaten + 1; 
            
            // Test si toutes les Feuilles ont été mangées
            if (leavesEaten == ((MangeWorld)getWorld()).nMaxFeuilles) Termine();
        }
    }
    
    /**
     * C'est terminé.
     */
    public void Termine()
    {
       Greenfoot.stop();
   }

   /**
     * Avance l'ours dans la direction courante.
     */
    public void move()
    {
        if (!canMove()) {
            return;
        }
                
        switch(direction) {
            case SOUTH :
                setLocation(getX(), getY() + 1);
                break;
            case EAST :
                setLocation(getX() + 1, getY());
                break;
            case NORTH :
                setLocation(getX(), getY() - 1);
                break;
            case WEST :
                setLocation(getX() - 1, getY());
                break;
        }
    }

    /**
     * Test si l'ours peut se déplacer.
     * S'il le peut, returne true sinon retourne false.
     */
    public boolean canMove()
    {
        World myWorld = getWorld();
        int x = getX();
        int y = getY();
        switch(direction) {
            case SOUTH :
                y++;
                break;
            case EAST :
                x++;
                break;
            case NORTH :
                y--;
                break;
            case WEST :
                x--;
                break;
        }
        // test for outside border
        if (x >= myWorld.getWidth() || y >= myWorld.getHeight()) {
            return false;
        }
        else if (x < 0 || y < 0) {
            return false;
        }
        return true;
    }

    /**
     * Se positionne dans la direction de déplacement.
     */
    public void setDirection(int direction)
    {
        this.direction = direction;
        switch(direction) {
            case SOUTH :
                setRotation(90);
                break;
            case EAST :
                setRotation(0);
                break;
            case NORTH :
                setRotation(270);
                break;
            case WEST :
                setRotation(180);
                break;
            default :
                break;
        }
    }
   
}